@@ -36,7 +36,7 @@ public:
 
 	virtual void start_measurement(void);
 	virtual void end_measurement(void);
-	virtual double joules_consumed(void);
+	virtual double power(void);
 
 	virtual double dev_capacity(void)
 	{
@@ -58,7 +58,9 @@ extern vector<class power_meter *> power_meters;
 
 extern void start_power_measurement(void);
 extern void end_power_measurement(void);
-extern double global_joules_consumed(void);
+extern double global_power(void);
+extern void global_sample_power(void);
+extern double global_joules(void);
 extern double global_time_left(void);
 
 extern void detect_power_meters(void);
